generateForAnnotatedElement method

  1. @override
FutureOr<String> generateForAnnotatedElement(
  1. Element element,
  2. ConstantReader annotation,
  3. BuildStep buildStep
)

Implement to return source code to generate for element.

This method is invoked based on finding elements annotated with an instance of T. The annotation is provided as a ConstantReader.

Supported return values include a single String or multiple String instances within an Iterable or Stream. It is also valid to return a Future of String, Iterable, or Stream.

Implementations should return null when no content is generated. Empty or whitespace-only String instances are also ignored.

Implementation

@override
FutureOr<String> generateForAnnotatedElement(
  Element element,
  ConstantReader annotation,
  BuildStep buildStep,
) async {
  if (element is! ClassElement) {
    throw InvalidGenerationSourceError(
        'Generator cannot target `${element.displayName}`.');
  }

  final buffer = StringBuffer();

  for (final accessor
      in element.accessors.where((f) => f.isStatic && f.isGetter)) {
    if (_typeCheckers.jsonSchemaChecker.hasAnnotationOf(accessor)) {
      final schema = _schemaGenerator.generateSchema(element);
      final name = await _getRedirectedVariableName(accessor, buildStep);
      if (name == null) {
        throw InvalidGenerationSourceError(
            'Failed to extract redirected variable name for ${accessor.displayName}.');
      }
      _writeSchemaToBuffer(buffer, name, accessor.returnType, schema);
    }
    // Add conditions for other schema types here
  }
  return buffer.toString();
}